#[non_exhaustive]pub enum CodecFormat {
Proto,
Json,
}Expand description
Supported codec formats.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl CodecFormat
impl CodecFormat
Sourcepub fn from_content_type(content_type: &str) -> Option<Self>
pub fn from_content_type(content_type: &str) -> Option<Self>
Parse codec format from content type string.
Sourcepub fn from_codec(codec: &str) -> Option<Self>
pub fn from_codec(codec: &str) -> Option<Self>
Parse codec format from encoding name (used in GET request query params).
Accepts “proto” or “json” (the values used in the encoding query parameter).
Sourcepub fn content_type(&self) -> &'static str
pub fn content_type(&self) -> &'static str
Get the content type string for this format (unary RPC).
Sourcepub fn streaming_content_type(&self) -> &'static str
pub fn streaming_content_type(&self) -> &'static str
Get the streaming content type string for this format.
Sourcepub fn is_streaming_content_type(content_type: &str) -> bool
pub fn is_streaming_content_type(content_type: &str) -> bool
Check if the given content type indicates a streaming request.