pub struct ConnectError {
pub code: ErrorCode,
pub message: Option<String>,
pub details: Vec<ErrorDetail>,
/* private fields */
}Expand description
A ConnectRPC error.
Fields
code: ErrorCodeThe error code.
message: Option<String>Human-readable error message.
details: Vec<ErrorDetail>Additional error details.
Implementations
Sourceimpl ConnectError
impl ConnectError
Sourcepub fn new(code: ErrorCode, message: impl Into<String>) -> Self
pub fn new(code: ErrorCode, message: impl Into<String>) -> Self
Create a new error with the given code and message.
Sourcepub fn with_headers(self, headers: HeaderMap) -> Self
pub fn with_headers(self, headers: HeaderMap) -> Self
Add response headers to be included in the error response.
Sourcepub fn with_trailers(self, trailers: HeaderMap) -> Self
pub fn with_trailers(self, trailers: HeaderMap) -> Self
Add response trailers to be included in the error response.
Sourcepub fn response_headers(&self) -> &HeaderMap
pub fn response_headers(&self) -> &HeaderMap
Borrow the response headers. Returns an empty map if none were set.
Sourcepub fn trailers(&self) -> &HeaderMap
pub fn trailers(&self) -> &HeaderMap
Borrow the response trailers. Returns an empty map if none were set.
Sourcepub fn response_headers_mut(&mut self) -> &mut HeaderMap
pub fn response_headers_mut(&mut self) -> &mut HeaderMap
Mutably borrow the response headers, allocating an empty map if none were set.
Sourcepub fn trailers_mut(&mut self) -> &mut HeaderMap
pub fn trailers_mut(&mut self) -> &mut HeaderMap
Mutably borrow the response trailers, allocating an empty map if none were set.
Sourcepub fn set_response_headers(&mut self, headers: HeaderMap)
pub fn set_response_headers(&mut self, headers: HeaderMap)
Replace the response headers. An empty map is stored as None.
Sourcepub fn set_trailers(&mut self, trailers: HeaderMap)
pub fn set_trailers(&mut self, trailers: HeaderMap)
Replace the response trailers. An empty map is stored as None.
Sourcepub fn with_http_status(self, status: StatusCode) -> Self
pub fn with_http_status(self, status: StatusCode) -> Self
Set an HTTP status override for this error.
When set, this overrides the default HTTP status derived from the error code. This is useful for HTTP-level errors like 415 Unsupported Media Type.
Sourcepub fn unsupported_media_type(message: impl Into<String>) -> Self
pub fn unsupported_media_type(message: impl Into<String>) -> Self
Create an error for unsupported media type (HTTP 415).
This is used when the client sends a content type that the server doesn’t support.
Sourcepub fn method_not_allowed(message: impl Into<String>) -> Self
pub fn method_not_allowed(message: impl Into<String>) -> Self
Create an error for method not allowed (HTTP 405).
This is used when the client uses an HTTP method other than POST.
Sourcepub fn invalid_argument(message: impl Into<String>) -> Self
pub fn invalid_argument(message: impl Into<String>) -> Self
Create an invalid argument error.
Sourcepub fn deadline_exceeded(message: impl Into<String>) -> Self
pub fn deadline_exceeded(message: impl Into<String>) -> Self
Create a deadline exceeded error.
Sourcepub fn already_exists(message: impl Into<String>) -> Self
pub fn already_exists(message: impl Into<String>) -> Self
Create an already exists error.
Sourcepub fn permission_denied(message: impl Into<String>) -> Self
pub fn permission_denied(message: impl Into<String>) -> Self
Create a permission denied error.
Sourcepub fn resource_exhausted(message: impl Into<String>) -> Self
pub fn resource_exhausted(message: impl Into<String>) -> Self
Create a resource exhausted error.
Sourcepub fn failed_precondition(message: impl Into<String>) -> Self
pub fn failed_precondition(message: impl Into<String>) -> Self
Create a failed precondition error.
Sourcepub fn out_of_range(message: impl Into<String>) -> Self
pub fn out_of_range(message: impl Into<String>) -> Self
Create an out of range error.
Sourcepub fn unimplemented(message: impl Into<String>) -> Self
pub fn unimplemented(message: impl Into<String>) -> Self
Create an unimplemented error.
Create an unavailable error.
Sourcepub fn unauthenticated(message: impl Into<String>) -> Self
pub fn unauthenticated(message: impl Into<String>) -> Self
Create an unauthenticated error.
Sourcepub fn with_detail(self, detail: ErrorDetail) -> Self
pub fn with_detail(self, detail: ErrorDetail) -> Self
Add an error detail.
Sourcepub fn http_status(&self) -> StatusCode
pub fn http_status(&self) -> StatusCode
Get the HTTP status code for this error.
Returns the HTTP status override if set, otherwise derives it from the error code.